// eslint-disable-next-line max-len
/* * ********************************************************************************************************************
 *
 *                      :*$@@%$*:                         ;:                ;;    ;;
 *                    :@@%!  :!@@%:                       %!             ;%%@@%$ =@@@@@@@%;     @%@@@%%%%@@@@@
 *                   :@%;       :$=                       %%$$$%$$         ;$$  ;$@=   !@$
 *                   =@!                                  %!              @ $=;%   !@@@%:      !$$$$$$$$$$$$$$=
 *                   =@*                                  %!              @ $= % %@=   =%@!      %=
 *              *$%%! @@=        ;=$%%%$*:                %!              @ $= % =%%%%%%@$      *%:         =%
 *            %@@!:    !@@@%=$@@@@%!  :*@@$:              %!              @ $= % $*     ;@      @*          :%*
 *          ;@@!          ;!!!;:         ;@%:      =======@%========*     @ $$ % $%*****$@     :@$=*********=@$
 *          $@*   ;@@@%=!:                *@*
 *          =@$    ;;;!=%@@@@=!           =@!
 *           %@$:      =@%: :*@@@*       %@=                    Copyright (c) 2016-2019.  北京上格云技术有限公司
 *            ;%@@$=$@@%*       *@@@$=%@@%;
 *               ::;::             ::;::                                              All rights reserved.
 *
 * ********************************************************************************************************************
 */

import { Opt } from "../types/Opt";
import { SGraphyItem } from "@saga-web/graphy/lib";
import { SColor, SPainter, SPoint, SPolygonUtil } from "@saga-web/draw/lib";
import { SMouseEvent } from "@saga-web/base/lib";
import { ItemOrder } from "../types/ItemOrder";

/**
 * 遮罩item
 *
 * @author  郝建龙
 */
export class ShadeItem extends SGraphyItem {
    /** 轮廓线坐标  */
    outLine: SPoint[] = [];

    /**
     * 构造函数
     *
     * @param parent    指向父对象
     * @param data      遮罩数据
     */
    constructor(parent: SGraphyItem | null, data: SPoint[]) {
        super(parent);
        this.outLine = data;
        this.zOrder = ItemOrder.shadeOrder;
    } // Constructor

    /**
     * 判断点是否在区域内
     *
     * @param x
     * @param y
     */
    contains(x: number, y: number): boolean {
        let arr = this.outLine;
        if (SPolygonUtil.pointIn(x, y, arr)) {
            return true;
        }
        return false;
    } // Function contains()

    /**
     * 鼠标点击事件
     *
     * @param	event         事件参数
     * @return	boolean
     */
    onMouseDown(event: SMouseEvent): boolean {
        this.$emit("mouseDown");
        return true;
    }

    /**
     * Item绘制操作
     *
     * @param   painter       painter对象
     * @param   rect          绘制区域
     */
    onDraw(painter: SPainter): void {
        painter.pen.color = SColor.Transparent;
        painter.pen.lineWidth = 10;
        painter.brush.color = Opt.sceneMarkColor;
        painter.drawPolygon(this.outLine);
    } // Function onDraw()
} // Class SceneMarkItem
